{% for testimonial in testimonials %}
    <div class="quotes">
        <p>{{ testimonial.testimony }}<span class="endquote">&nbsp;</span></p>
        <p><strong>
            {{ testimonial.author }}
        </strong></p>
    </div>
{% endfor %}
