{%  if testimonials.count > 0 %}
<div class="quotes">
    <span>{{ instance.block }}</span>
    {% for testimonial in testimonials %}
        <p><span class="hanginquote">"</span>{{ testimonial.testimony }}"</p>
        <div class="quoteauthor">
            {{ testimonial.author }}
        </div>
    {% endfor %}
</div>
{%  endif %}
